@@ -190,7 +190,9 @@ bool fullscreen=false;
 							"\t-cyclemult 0-10\tCPU cycle multiplier\n"
 							"\t-ilace 0,1,3,7\tInterlace lines\n"
 							"\t-abbeyfix\tEnabling Abbeyfix\n"
-							"\tFILE\t\tCdRom file\n"));
+							"\t-fullscreen\tEnabling scaling"
+							"\tFILE\t\tCdRom file\n\n"
+							"bugtracker at http://code.google.com/p/psx4m/issues/list"));
 			 return 0;
 		} else file = argv[i];
 	}
@@ -297,15 +299,7 @@ int SysInit() {
 #endif
 
 
-if (Config.PsxOut)
-{
-	emuLog = stdout;
-}
-else
-{
-	emuLog = fopen("emuLog.txt","wb");
-}
-
+emuLog = stdout;
 setvbuf(emuLog, NULL, _IONBF, 0);
 
 
