@@ -19,6 +19,6 @@
 #ifndef __PSXHLE_H__
 #define __PSXHLE_H__
 
-extern void (*psxHLEt[256])();
+extern u32 (*psxHLEt[256])();
 
 #endif /* __PSXHLE_H__ */
