@@ -14,6 +14,8 @@ GtkWidget *window, *drawing;
 #define Y_RES           480
 #define D_WIDTH			640
 #define D_HEIGHT		480
+#define F_WIDTH			800
+#define F_HEIGHT		480
 		
 int screen_size;
 unsigned short* screenbuffer = NULL;
@@ -24,7 +26,7 @@ int keymap[65536];
 char *cfile;
 char *loadst;
 char *file;
-
+bool fullscreen;
 void hildon_quit()
 {
 	gp2x_deinit();
@@ -39,9 +41,9 @@ window_key_proxy (GtkWidget *widget,
 {
 	unsigned long key = 0;
 	
-	//printf("%d\n",event->keyval);		
+if (keymap[event->keyval]==-1)return;
 
-	switch(keymap[event->keyval]){
+switch(keymap[event->keyval]){
 	case 0:
 			key = GP2X_LEFT;break;
 	case 1:
@@ -80,7 +82,7 @@ window_key_proxy (GtkWidget *widget,
 			keys &= ~GP2X_LEFT;
 			keys &= ~GP2X_UP;
 			}
-			key = 0;break;
+		key = -1;			return ;			break;
 	case 16:
 			if (event->type == GDK_KEY_PRESS){
 			keys |= GP2X_RIGHT;
@@ -89,7 +91,7 @@ window_key_proxy (GtkWidget *widget,
 			keys &= ~GP2X_RIGHT;
 			keys &= ~GP2X_UP;
 			}
-			key = 0;break;
+		key = -1;			return ;			break;
 	case 17:
 			if (event->type == GDK_KEY_PRESS){
 			keys |= GP2X_LEFT;
@@ -98,7 +100,7 @@ window_key_proxy (GtkWidget *widget,
 			keys &= ~GP2X_LEFT;
 			keys &= ~GP2X_DOWN;
 			}
-			key = 0;break;
+		key = -1;			return ;			break;
 	case 18:
 			if (event->type == GDK_KEY_PRESS){
 			keys |= GP2X_RIGHT;
@@ -107,18 +109,16 @@ window_key_proxy (GtkWidget *widget,
 			keys &= ~GP2X_RIGHT;
 			keys &= ~GP2X_DOWN;
 			}
-			key = 0;break;
+		key = -1;			return ;			break;
 	case 19:
 		SaveState(cfile);
-		key = 0;break;
+		key = -1;			return ;			break;
 	break;
 	case 20:
 		LoadState(cfile);
-		key = 0;break;
+		key = -1;			return ;			break;
 	break;
-	default:
-			key = 0;break;
-	}
+}
 	
 	if (event->type == GDK_KEY_PRESS) {
 		keys |= key;
@@ -130,10 +130,13 @@ window_key_proxy (GtkWidget *widget,
 }
 
 
-void hildon_init(int *argc, char ***argv,char *fl,char* lst,bool fullscreen)
+void hildon_init(int *argc, char ***argv,char *fl,char* lst,bool fscreen)
 {
+fullscreen=fscreen;
 	file=fl;
-	cfile="/opt/usr/psx4m/savestate";
+	
+	sprintf (cfile, "%s.save-%s", file,lst);
+	
 	loadst=lst;
 
 	// read key config
@@ -158,26 +161,21 @@ void hildon_init(int *argc, char ***argv,char *fl,char* lst,bool fullscreen)
 	window = hildon_stackable_window_new ();
 	gtk_widget_realize (window);
 	gtk_window_fullscreen (GTK_WINDOW(window));
-	g_signal_connect (G_OBJECT (window), "key-press-event",
-				G_CALLBACK (window_key_proxy), NULL);
-	g_signal_connect (G_OBJECT (window), "key-release-event",
-				G_CALLBACK (window_key_proxy), NULL);
-	g_signal_connect (G_OBJECT (window), "delete_event",
-				G_CALLBACK (hildon_quit), NULL);
-	gtk_widget_add_events (window,
-				GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK);
+	g_signal_connect (G_OBJECT (window), "key-press-event",		G_CALLBACK (window_key_proxy), NULL);
+	g_signal_connect (G_OBJECT (window), "key-release-event",	G_CALLBACK (window_key_proxy), NULL);
+	g_signal_connect (G_OBJECT (window), "delete_event",		G_CALLBACK (hildon_quit), NULL);
+	gtk_widget_add_events (window, GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK);
 
 	actor = HILDON_ANIMATION_ACTOR (hildon_animation_actor_new());
-	if (!fullscreen){
-	hildon_animation_actor_set_position (actor, (X_RES - D_WIDTH)/2, (Y_RES - D_HEIGHT)/2 );
+	if (fullscreen){
+	hildon_animation_actor_set_position (actor, (X_RES - F_WIDTH)/2, (Y_RES - F_HEIGHT)/2 );
 	}else{
-	hildon_animation_actor_set_position (actor, 0, 0 );
+	hildon_animation_actor_set_position (actor, (X_RES - D_WIDTH)/2, (Y_RES - D_HEIGHT)/2 );
 	
 	}
 	hildon_animation_actor_set_parent (actor, GTK_WINDOW (window));
 
 	drawing = gtk_image_new ();
-if (fullscreen)	gp2x_change_res(800,480);
 	gtk_container_add (GTK_CONTAINER (actor), drawing);
 
 	gtk_widget_show_all (GTK_WIDGET (actor));
@@ -186,34 +184,31 @@ if (fullscreen)	gp2x_change_res(800,480);
 
 void gp2x_change_res(int w, int h)
 {
-	SysPrintf ("PSX resolution change: %dx%d", w, h);
+	if (Config.PsxOut)SysPrintf ("PSX resolution change: %dx%d", w, h);
 	
 	if (w <= 0 || h <= 0)
 		return;
 	
-	if (Config.PsxOut) printf ("trying ...;\n");
-
-	if (Config.PsxOut) printf ("destroing;\n");
 	if (image) gdk_image_destroy(image);
-	if (Config.PsxOut) printf ("creating;\n");
 	image = gdk_image_new( GDK_IMAGE_FASTEST, gdk_visual_get_system(), w, h );
 
-	if (Config.PsxOut) printf ("screen buffer;\n");
 	screenbuffer = (unsigned short*) image->mem;
-	if (Config.PsxOut) printf ("screen size;\n");
 	screen_size = image->bpl * (h / (linesInterlace_user+1)) * image->bpp;
 
-	if (Config.PsxOut) printf ("img from file;\n");
 	gtk_image_set_from_image (GTK_IMAGE(drawing), image, NULL);
 
-	if (Config.PsxOut) printf ("resizing;\n");
 	gtk_window_resize (GTK_WINDOW (actor), w, h);
 	
-	if (Config.PsxOut) printf ("scaling;\n");
+	if (!fullscreen){
 	hildon_animation_actor_set_scale (actor,
 				(gdouble)D_WIDTH / (gdouble)w,
 				(gdouble)D_HEIGHT / (gdouble)h
-	);
+	);}
+	else{
+		hildon_animation_actor_set_scale (actor,
+				(gdouble)F_WIDTH / (gdouble)w,
+				(gdouble)F_HEIGHT / (gdouble)h
+	);}
 	
 }
 
